Sim2L
=====

.. autoclass:: nanohubremote.session.Sim2L
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

The Sim2L class provides methods for interacting with Jupyter-based Sim2L tools.
